fileStorageDir property
If fileStorageDir is provided, the cookie storage will be migrated
from the FileStorage to HiveCookieStorage.
Implementation
final String? fileStorageDir;
If fileStorageDir is provided, the cookie storage will be migrated
from the FileStorage to HiveCookieStorage.
final String? fileStorageDir;